@@ -74,7 +74,6 @@ PREVIEW_FILE = "preview.png"
 NO_PREVIEW_FILE = "fallback_thumb.png"
 
 _gmic_found = False
-_gmic_version = 1
 _session_id = None
 
 _window = None
@@ -107,23 +106,6 @@ def test_availablity():
         _gmic_found = True
     else:
         print("G'MIC NOT found")
-
-def get_gmic_version():
-    gmic_ver = 1
-    cmd = "gmic -version"
-    process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
-    output, error = process.communicate()
-    tokens = output.split()
-    clended = []
-    for token in tokens:
-        token = token.decode("utf-8")
-        str1 = token.replace('.','')
-        str2 = str1.replace(',','')
-        if str2.isdigit(): # this is based on assumtion that str2 ends up being number like "175" or 215" etc. only for version number token
-            if str2[0] == '2':
-                gmic_ver = 2
-
-    return gmic_ver
                 
 def gmic_available():
     return _gmic_found
@@ -174,16 +156,9 @@ def main(root_path, force_launch=False):
     # Set paths.
     respaths.set_paths(root_path)
 
-    # Check G'MIC version
-    global _gmic_version
-    _gmic_version = get_gmic_version()
-    if _gmic_version == 2:
-        respaths.set_gmic2(root_path)
-
     # Write stdout to log file
     userfolders.init()
     sys.stdout = open(userfolders.get_cache_dir() + "log_gmic", 'w')
-    print("G'MIC version:", str(_gmic_version))
 
     # Init gmic tool session dirs
     if os.path.exists(get_session_folder()):
@@ -195,10 +170,6 @@ def main(root_path, force_launch=False):
 
     # Load editor prefs and apply themes
     editorpersistance.load()
-    if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
-        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
-        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
-            gui.apply_gtk_css()
             
     # Init translations module with translations data
     translations.init_languages()
@@ -226,8 +197,10 @@ def main(root_path, force_launch=False):
     if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
         respaths.apply_dark_theme()
         Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme", True)
-        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME:
-            gui.apply_gtk_css()
+        if editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME \
+            or editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME_GRAY \
+            or editorpersistance.prefs.theme == appconsts.FLOWBLADE_THEME_NEUTRAL:
+            gui.apply_gtk_css(editorpersistance.prefs.theme)
 
     repo = mlt.Factory().init()
     processutils.prepare_mlt_repo(repo)
